@@ -48,7 +48,7 @@ class BaseModel(PydanticBaseModel):
         extra = "forbid"
 
 
-class Auto(Enum):
+class Auto(str, Enum):
     """
     An enumeration just containing auto
 
@@ -57,7 +57,7 @@ class Auto(Enum):
     auto = "auto"
 
 
-class ShapeType(Enum):
+class ShapeType(str, Enum):
     """
     An enumeration of sample shape types
 
@@ -95,7 +95,22 @@ class Cylinder(BaseModel):
     """
 
     length: float = Field(0, description="The cylinder length (A)", gt=0)
-    radius: float = Field(0, description="The cylinder radius (A)", gt=0)
+
+    radius: Union[float, List[float]] = Field(
+        0, description="The cylinder radius (A)", gt=0
+    )
+
+    axis: Tuple[float, float, float] = Field(
+        (0, 1, 0), description="The axis of the cylinder"
+    )
+
+    offset_x: List[float] = Field(
+        None, description="The x offset as a function of cylinder y position"
+    )
+
+    offset_z: List[float] = Field(
+        None, description="The z offset as a function of cylinder y position"
+    )
 
 
 class Shape(BaseModel):
@@ -178,6 +193,7 @@ class LocalMolecule(BaseModel):
     )
 
     instances: Union[int, List[MoleculePose]] = Field(
+        1,
         description=(
             "The instances of the molecule to put into the sample model. This "
             "field can be set as either an integer or a list of MoleculePose "
@@ -207,6 +223,7 @@ class PDBMolecule(BaseModel):
     )
 
     instances: Union[int, List[MoleculePose]] = Field(
+        1,
         description=(
             "The instances of the molecule to put into the sample model. This "
             "field can be set as either an integer or a list of MoleculePose "
@@ -296,39 +313,6 @@ class Sample(BaseModel):
     )
 
 
-class DriftType(Enum):
-    """
-    An enumeration to describe the beam and defocus drift type
-
-    """
-
-    random = "random"
-    random_smoothed = "random_smoothed"
-    sinusoidal = "sinusoidal"
-
-
-class BeamDrift(BaseModel):
-    """
-    A model to describe the beam drift
-
-    """
-
-    type: DriftType = Field(None, description="The beam drift type")
-
-    magnitude: float = Field(0, description="The magnitude of the beam drift (A)")
-
-
-class DefocusDrift(BaseModel):
-    """
-    A model to describe the defocus drift
-
-    """
-
-    type: DriftType = Field(None, description="The defocus drift type")
-
-    magnitude: float = Field(0, description="The magnitude of the defocus drift (A)")
-
-
 class Beam(BaseModel):
     """
     A model to describe the beam
@@ -353,12 +337,6 @@ class Beam(BaseModel):
 
     phi: float = Field(0, description="The beam tilt phi angle (deg)")
 
-    drift: Optional[BeamDrift] = Field(description="The beam drift model parameters")
-
-    defocus_drift: Optional[DefocusDrift] = Field(
-        description="The defocus drift model parameters"
-    )
-
 
 class Lens(BaseModel):
     """
@@ -440,7 +418,7 @@ class Detector(BaseModel):
     )
 
 
-class MicroscopeModel(Enum):
+class MicroscopeModel(str, Enum):
     """
     An enumeration to describe the microscope model
 
@@ -469,7 +447,7 @@ class Microscope(BaseModel):
     detector: Detector = Field(Detector(), description="The detector model parameters")
 
 
-class ScanMode(Enum):
+class ScanMode(str, Enum):
     """
     An enumeration to describe the scan mode
 
@@ -480,6 +458,19 @@ class ScanMode(Enum):
     dose_symmetric = "dose_symmetric"
     single_particle = "single_particle"
     helical_scan = "helical_scan"
+    nhelix = "nhelix"
+    beam_tilt = "beam_tilt"
+
+
+class Drift(BaseModel):
+    """
+    A model to describe the beam drift
+
+    """
+
+    magnitude: float = Field(0, description="The magnitude of the drift (A)")
+
+    kernel_size: int = Field(0, description="How much to smooth the drift")
 
 
 class Scan(BaseModel):
@@ -508,6 +499,8 @@ class Scan(BaseModel):
 
     num_images: int = Field(1, description="The number of images to simulate")
 
+    num_nhelix: int = Field(1, description="The number of scans in an n-helix")
+
     exposure_time: float = Field(1, description="The exposure time per image (s)")
 
     angles: Optional[List[float]] = Field(
@@ -526,8 +519,26 @@ class Scan(BaseModel):
         ),
     )
 
+    theta: Optional[Union[float, List[float]]] = Field(
+        None,
+        description=(
+            "The list of theta angles to use (mrad) for the beam tilt."
+            "This must either be the same length as phi or a scalar"
+        ),
+    )
 
-class InelasticModel(Enum):
+    phi: Optional[Union[float, List[float]]] = Field(
+        None,
+        description=(
+            "The list of phi angles to use (mrad) for the beam tilt."
+            "This must either be the same length as theta or a scalar"
+        ),
+    )
+
+    drift: Optional[Drift] = Field(description="The drift model parameters")
+
+
+class InelasticModel(str, Enum):
     """
     A model to describe the inelastic scattering mode
 
@@ -539,7 +550,7 @@ class InelasticModel(Enum):
     cc_corrected = "cc_corrected"
 
 
-class MPLPosition(Enum):
+class MPLPosition(str, Enum):
     """
     A model to describe the MPL position mode
 
@@ -586,7 +597,7 @@ class Simulation(BaseModel):
     )
 
 
-class ClusterMethod(Enum):
+class ClusterMethod(str, Enum):
     """
     An enumeration to describe the cluster method
 
@@ -606,7 +617,7 @@ class Cluster(BaseModel):
     max_workers: int = Field(1, description="The maximum number of worker processes")
 
 
-class Device(Enum):
+class Device(str, Enum):
     """
     An enumeration to set whether to run on the GPU or CPU
 
