@@ -522,7 +522,7 @@ class AtomData(object):
                 self.data["y"].astype("float32"),
                 self.data["z"].astype("float32"),
                 self.data["sigma"].astype("float32"),
-                [float(1) for i in range(self.data.shape[0])],
+                self.data["occupancy"].astype("float32"),
                 [int(0) for i in range(self.data.shape[0])],
                 self.data["charge"].astype("uint8"),
             )
@@ -575,7 +575,7 @@ class AtomData(object):
                                 atom.pos.y,
                                 atom.pos.z,
                                 get_atom_sigma(atom),
-                                atom.occ,
+                                1,  # atom.occ,
                                 atom.charge,
                             )
 
@@ -1095,7 +1095,8 @@ class SampleHDF5Adapter(object):
 
             # Set the shape attributes
             for key, value in shape[shape["type"]].items():
-                self.__handle["shape"].attrs[key] = value
+                if value is not None:
+                    self.__handle["shape"].attrs[key] = value
 
             # Set the margin
             self.__handle["shape"].attrs["margin"] = shape.get("margin", (0, 0, 0))
@@ -1341,6 +1342,7 @@ class Sample(object):
 
         # Add the molecule to it's own field
         if name is not None:
+            name = name.replace("/", "_").replace("\\", "_").replace(".", "_")
             self.__handle.sample.molecules[name].atoms = atoms.data
             self.__handle.sample.molecules[name].positions = positions
             self.__handle.sample.molecules[name].orientations = orientations
@@ -1905,9 +1907,7 @@ class AtomDeleter(object):
         # pylab.imshow(self.grid[:,:,grid_shape[2]//2])
         # pylab.show()
 
-        self.grid = (
-            scipy.ndimage.morphology.distance_transform_edt(self.grid) < min_distance
-        )
+        self.grid = scipy.ndimage.distance_transform_edt(self.grid) < min_distance
         return
         # self.grid = scipy.ndimage.morphology.binary_closing(self.grid, iterations=2)
         # self.grid = scipy.ndimage.morphology.binary_fill_holes(self.grid)
